==> tkvoice-1.1.tar.gz: tkvoice-1.1/install.sh <==
#!/bin/sh
#
TKVOICE=tkvoice-1.1
#
echo -e "\f"
echo "*************************************************"
echo "*                                               *"
echo "*  $TKVOICE installation script             *"
echo "*  _______________________________________      *"
echo "*                                               *"
echo "*  You must be the \"root\" user to run this      *"
echo "*                                               *"
echo "*************************************************"
INSTALLDIR=`pwd`
if [ "$INSTALLDIR" == "/usr/local/tkvoice-1.1" ]
then
   echo -e "\finstalling tkvoice in $INSTALLDIR"
else
   echo -e "\finstalling tkvoice in $INSTALLDIR"
fi   
echo -e "\nAre you ready to install  ? (y/n)\c"
read answer
if [ "$answer" != "y" -a "$answer" != "Y" ]
then
    echo "Exiting ... you can run install.sh at a later date"
    exit 0
fi

# check user
USER=`env|grep USER|awk -F "=" '{print $2}'`
echo -e "\nChecking USER name...."
if [ "$USER" != "root" -a "$answer" != "ROOT" ]
then
    echo "exiting due to: USER=$USER"
    exit 0
else
    echo "USER=$USER ...proceeding"
fi
sleep 1
#
# check for tcl/tk wish
WISH=`type wish 2>&1|awk '{print $3}'`
if test -x $WISH
then
    echo -e "\nFound WISH: $WISH ...proceeding" 
else
    echo -e "\nexiting due to: tcl/tk WISH not found"
    echo -e "\nInstall tcl/tk and try again\n\n"
    exit 0
fi
sleep 1
# check for PVFTOOLS
for x in rmdtopvf pvftowav pvfspeed wavtopvf
do
  PVFTOOL=`type $x 2>&1|awk '{print $3}'`
echo "PVFTOOL=$PVFTOOL"
  if test -x $PVFTOOL
  then
    echo -e "\nFound $x: $PVFTOOL" 
    echo "Make sure this is in your PATH ...proceeding" 
    sleep 1
  else
    echo -e "\n$x was not found"
    echo -e "\nDid you install vgetty ?"
    echo -e "\n$TKVOICE will not work properly without $x"
    echo -e "\nContinue with installation  ? (y/n)\c"
    read answer
      if [ "$answer" != "y" -a "$answer" != "Y" ]
      then
       echo -e "\nExiting ... you can run install.sh at a later date\n"
       exit 0
      fi
  fi
done
#
# compile wavplay tools
echo -e "\nCompiling wavplay tools........."
cd $INSTALLDIR/wavplay-1.4/
make clean
make no_x
echo -e "\nDone compiling........."
echo -e "\nChecking executables..."

if test -x wavplay
then
   echo -e "\nwavplay has been successfully compiled !!!"
else
   echo -e "\nwavplay did not compile"
   echo -e "\nDo you want to try a pre-compiled version for linux-i486 ? (y/n)\c"
       read answer
       if [ "$answer" = "y" -o "$answer" = "Y" ]
       then
          echo -e "\nOk using pre-compiled version of wavplay for linux-i486."
          cp $INSTALLDIR/wavplay-1.4/wavplay.i486 $INSTALLDIR/wavplay-1.4/wavplay
       fi       
fi
if test -x wavrec
then
   echo -e "\nwavrec has been successfully compiled !!!"
else
   echo -e "\nwavrec did not compile"
   echo -e "\nDo you want to try a pre-compiled version for linux-i486 ? (y/n)\c"
       read answer
       if [ "$answer" = "y" -o "$answer" = "Y" ]
       then
          echo -e "\nOk using pre-compiled version of wavrec for linux-i486."
          cp $INSTALLDIR/wavplay-1.4/wavrec.i486 $INSTALLDIR/wavplay-1.4/wavrec
       fi       
fi

#
# set uid ?
echo -e "\n"
echo -e "Do you want to set wavplay and wavrec UID ? (y/n)\c"
read answer
if [ "$answer" != "y" -a "$answer" != "Y" ]
then
    echo -e "\nNot setting UID......None root users may have problems"
else
    echo -e "\nSetting UID......for wavplay and wavrec"
    chmod +s wavplay wavrec   
fi         

cd $INSTALLDIR
cd ..
rm -f tkvoice
ln -sf $TKVOICE tkvoice
cd $INSTALLDIR
ln -sf $INSTALLDIR/tkvoice /usr/local/bin/tkvoice
rm ~/.tkvoice/tkvoicepaths.dat 2>/dev/null
# Start up tkvoice
echo -e "\nStarting TKVOICE...."
echo -e "Please check your install PATH (under OPTIONS) and save your settings"
sleep 4

$INSTALLDIR/tkvoice

==> tkvoice-1.2a.tar.gz: tkvoice-1.2a/install.sh <==
#!/bin/sh
#
TKVOICE=tkvoice-1.2a
#
echo -e "\f"
echo "*************************************************"
echo "*                                               *"
echo "*  $TKVOICE installation script             *"
echo "*  _______________________________________      *"
echo "*                                               *"
echo "*  You must be the \"root\" user to run this      *"
echo "*                                               *"
echo "*************************************************"
INSTALLDIR=`pwd`
if [ "$INSTALLDIR" == "/usr/local/$TKVOICE" ]
then
   echo -e "\finstalling tkvoice in STANDARD directory $INSTALLDIR"
else
   echo -e "\finstalling tkvoice in NON-Standard dir. $INSTALLDIR"
fi   
echo -e "\nAre you ready to install  ? (y/n)\c"
read answer
if [ "$answer" != "y" -a "$answer" != "Y" ]
then
    echo "Exiting ... you can run install.sh at a later date"
    exit 0
fi

# check user
USER=`env|grep USER|awk -F "=" '{print $2}'`
echo -e "\nChecking USER name...."
if [ "$USER" != "root" -a "$answer" != "ROOT" ]
then
    echo "exiting due to: USER=$USER"
    exit 0
else
    echo "USER=$USER ...proceeding"
fi
sleep 1
#
# check for tcl/tk wish
WISH=`type wish 2>&1|awk '{print $3}'`
if test -x $WISH
then
    echo -e "\nFound WISH: $WISH ...proceeding" 
else
    echo -e "\nexiting due to: tcl/tk WISH not found"
    echo -e "\nInstall tcl/tk and try again\n\n"
    exit 0
fi
sleep 1
# check for PVFTOOLS
for x in rmdtopvf pvftowav pvfspeed wavtopvf
do
  PVFTOOL=`type $x 2>&1|awk '{print $3}'`
echo "PVFTOOL=$PVFTOOL"
  if test -x $PVFTOOL
  then
    echo -e "\nFound $x: $PVFTOOL" 
    echo "Make sure this is in your PATH ...proceeding" 
    sleep 1
  else
    echo -e "\n$x was not found"
    echo -e "\nDid you install vgetty ?"
    echo -e "\n$TKVOICE will not work properly without $x"
    echo -e "\nContinue with installation  ? (y/n)\c"
    read answer
      if [ "$answer" != "y" -a "$answer" != "Y" ]
      then
       echo -e "\nExiting ... you can run install.sh at a later date\n"
       exit 0
      fi
  fi
done
#
# compile wavplay tools
echo -e "\nCompiling wavplay tools........."
cd $INSTALLDIR/wavplay-1.4/
make clean
make no_x
echo -e "\nDone compiling........."
echo -e "\nChecking executables..."

if test -x wavplay
then
   echo -e "\nwavplay has been successfully compiled !!!"
else
   echo -e "\nwavplay did not compile"
   echo -e "\nDo you want to try a pre-compiled version for linux-i486 ? (y/n)\c"
       read answer
       if [ "$answer" = "y" -o "$answer" = "Y" ]
       then
          echo -e "\nOk using pre-compiled version of wavplay for linux-i486."
          cp $INSTALLDIR/wavplay-1.4/wavplay.i486 $INSTALLDIR/wavplay-1.4/wavplay
       fi       
fi
if test -x wavrec
then
   echo -e "\nwavrec has been successfully compiled !!!"
else
   echo -e "\nwavrec did not compile"
   echo -e "\nDo you want to try a pre-compiled version for linux-i486 ? (y/n)\c"
       read answer
       if [ "$answer" = "y" -o "$answer" = "Y" ]
       then
          echo -e "\nOk using pre-compiled version of wavrec for linux-i486."
          cp $INSTALLDIR/wavplay-1.4/wavrec.i486 $INSTALLDIR/wavplay-1.4/wavrec
       fi       
fi

#
# set uid ?
echo -e "\n"
echo -e "Do you want to set wavplay and wavrec UID ? (y/n)\c"
read answer
if [ "$answer" != "y" -a "$answer" != "Y" ]
then
    echo -e "\nNot setting UID......None root users may have problems"
else
    echo -e "\nSetting UID......for wavplay and wavrec"
    chmod +s wavplay wavrec   
fi         
# check for FAX & NETPBM tools
for x in g32pbm pbmtoxbm pbmtolps
do
  PBMTOOL=`type $x 2>&1|awk '{print $3}'`
echo "PBMTOOL=$PBMTOOL"
  if test -x $PBMTOOL
  then
    echo -e "\nFound $x: $PBMTOOL" 
    echo "Make sure this is in your PATH ...proceeding" 
    sleep 1
  else
    echo -e "\n$x was not found"
    echo -e "\nDid you install netpbm tools?"
    echo -e "\n$TKVOICE will not view/print FAX messages without $x"
    echo -e "\nContinue with installation  ? (y/n)\c"
    read answer
      if [ "$answer" != "y" -a "$answer" != "Y" ]
      then
       echo -e "\nExiting ... you can run install.sh at a later date\n"
       exit 0
      fi
  fi
done
#

cd $INSTALLDIR
cd ..
rm -f tkvoice
ln -sf $TKVOICE tkvoice
cd $INSTALLDIR
ln -sf $INSTALLDIR/tkvoice /usr/local/bin/tkvoice
rm ~/.tkvoice/tkvoicepaths.dat 2>/dev/null
rm ~/.tkvoice/tkvoicevoice.dat 2>/dev/null
# Start up tkvoice
echo -e "\nStarting TKVOICE...."
echo -e "Please check your install PATH (under OPTIONS) and save your settings"

$INSTALLDIR/tkvoice
